/* eslint-disable sort-exports/sort-exports */
/**
 * Used by the following grid entity types:
 * - GridEntityType.ROCK (2)
 * - GridEntityType.ROCK_TINTED (4)
 * - GridEntityType.ROCK_BOMB (5)
 * - GridEntityType.ROCK_ALT (6)
 * - GridEntityType.STATUE (21) (only for Angel Statues)
 * - GridEntityType.ROCK_SS (22)
 * - GridEntityType.ROCK_SPIKED (25)
 * - GridEntityType.ROCK_ALT2 (26)
 * - GridEntityType.ROCK_GOLD (27)
 */
export var RockState;
(function (RockState) {
    RockState[RockState["UNBROKEN"] = 1] = "UNBROKEN";
    RockState[RockState["BROKEN"] = 2] = "BROKEN";
    /**
     * Only applies for `GridEntityType.ROCK_BOMB` (5). After being bombed, the rock stays in this
     * state for 4 frames, then changes to `RockState.BROKEN`.
     */
    RockState[RockState["EXPLODING"] = 3] = "EXPLODING";
    /** Only applies for `GridEntityType.ROCK_SS` (22), since it takes two bombs to break. */
    RockState[RockState["HALF_BROKEN"] = 4] = "HALF_BROKEN";
})(RockState || (RockState = {}));
/** For `GridEntityType.PIT` (7). */
export var PitState;
(function (PitState) {
    PitState[PitState["NORMAL"] = 0] = "NORMAL";
    /**
     * Pits can become filled when nearby rocks are bombed into them.
     *
     * Note that the ladder collectible does not change the state to this.
     */
    PitState[PitState["FILLED"] = 1] = "FILLED";
})(PitState || (PitState = {}));
/** For `GridEntityType.SPIKES_ON_OFF` (9). */
export var SpikesOnOffState;
(function (SpikesOnOffState) {
    SpikesOnOffState[SpikesOnOffState["ON"] = 0] = "ON";
    SpikesOnOffState[SpikesOnOffState["OFF"] = 1] = "OFF";
})(SpikesOnOffState || (SpikesOnOffState = {}));
/** For `GridEntityType.SPIDERWEB` (10). */
export var SpiderWebState;
(function (SpiderWebState) {
    SpiderWebState[SpiderWebState["UNBROKEN"] = 0] = "UNBROKEN";
    SpiderWebState[SpiderWebState["BROKEN"] = 1] = "BROKEN";
})(SpiderWebState || (SpiderWebState = {}));
/** For `GridEntityType.LOCK` (11). */
export var LockState;
(function (LockState) {
    LockState[LockState["LOCKED"] = 0] = "LOCKED";
    /**
     * Note that the locked block will turn to this state as soon as the key is inserted and stays
     * this state after disappearing. Thus, unlike the `RockState.BROKEN` enum, you cannot use this
     * state as a proxy for being able to move through the grid entity.
     */
    LockState[LockState["UNLOCKED"] = 1] = "UNLOCKED";
})(LockState || (LockState = {}));
/**
 * For `GridEntityType.TNT` (12).
 *
 * The health of a TNT barrel is represented by its state. It starts at 0 and climbs upwards in
 * increments of 1. Once the state reaches 4, the barrel explodes, and remains at state 4.
 *
 * Breaking a TNT barrel usually takes 4 tears. However, it is possible to take less than that if
 * the players damage is high enough. (High damage causes the tear to do two or more increments at
 * once.)
 */
export var TNTState;
(function (TNTState) {
    TNTState[TNTState["UNDAMAGED"] = 0] = "UNDAMAGED";
    TNTState[TNTState["ONE_QUARTER_DAMAGED"] = 1] = "ONE_QUARTER_DAMAGED";
    TNTState[TNTState["TWO_QUARTERS_DAMAGED"] = 2] = "TWO_QUARTERS_DAMAGED";
    TNTState[TNTState["THREE_QUARTERS_DAMAGED"] = 3] = "THREE_QUARTERS_DAMAGED";
    TNTState[TNTState["EXPLODED"] = 4] = "EXPLODED";
})(TNTState || (TNTState = {}));
/**
 * For `GridEntityType.POOP` (14).
 *
 * The health of a poop is represented by its state. It starts at 0 and climbs upwards in increments
 * of 250. Once the state reaches 1000, the poop is completely broken.
 *
 * Breaking a poop usually takes 4 tears. However, it is possible to take less than that if the
 * players damage is high enough. (High damage causes the tear to do two or more increments at
 * once.)
 *
 * Giga Poops increment by 20 instead of 250. Thus, they take around 50 tears to destroy.
 */
export var PoopState;
(function (PoopState) {
    PoopState[PoopState["UNDAMAGED"] = 0] = "UNDAMAGED";
    PoopState[PoopState["ONE_QUARTER_DAMAGED"] = 250] = "ONE_QUARTER_DAMAGED";
    PoopState[PoopState["TWO_QUARTERS_DAMAGED"] = 500] = "TWO_QUARTERS_DAMAGED";
    PoopState[PoopState["THREE_QUARTERS_DAMAGED"] = 750] = "THREE_QUARTERS_DAMAGED";
    PoopState[PoopState["COMPLETELY_DESTROYED"] = 1000] = "COMPLETELY_DESTROYED";
})(PoopState || (PoopState = {}));
/** For `GridEntityType.DOOR` (16). */
export var DoorState;
(function (DoorState) {
    DoorState[DoorState["INIT"] = 0] = "INIT";
    DoorState[DoorState["CLOSED"] = 1] = "CLOSED";
    DoorState[DoorState["OPEN"] = 2] = "OPEN";
    DoorState[DoorState["ONE_CHAIN"] = 3] = "ONE_CHAIN";
    DoorState[DoorState["HALF_CRACKED"] = 4] = "HALF_CRACKED";
})(DoorState || (DoorState = {}));
/** For `GridEntityType.TRAPDOOR` (17). */
export var TrapdoorState;
(function (TrapdoorState) {
    TrapdoorState[TrapdoorState["CLOSED"] = 0] = "CLOSED";
    TrapdoorState[TrapdoorState["OPEN"] = 1] = "OPEN";
})(TrapdoorState || (TrapdoorState = {}));
/** For `GridEntityType.CRAWL_SPACE` (18). */
export var CrawlSpaceState;
(function (CrawlSpaceState) {
    CrawlSpaceState[CrawlSpaceState["CLOSED"] = 0] = "CLOSED";
    CrawlSpaceState[CrawlSpaceState["OPEN"] = 1] = "OPEN";
})(CrawlSpaceState || (CrawlSpaceState = {}));
/** For `GridEntityType.PRESSURE_PLATE` (20). */
export var PressurePlateState;
(function (PressurePlateState) {
    PressurePlateState[PressurePlateState["UNPRESSED"] = 0] = "UNPRESSED";
    PressurePlateState[PressurePlateState["STATE_1_UNKNOWN"] = 1] = "STATE_1_UNKNOWN";
    PressurePlateState[PressurePlateState["STATE_2_UNKNOWN"] = 2] = "STATE_2_UNKNOWN";
    PressurePlateState[PressurePlateState["PRESSURE_PLATE_PRESSED"] = 3] = "PRESSURE_PLATE_PRESSED";
    PressurePlateState[PressurePlateState["REWARD_PLATE_PRESSED"] = 4] = "REWARD_PLATE_PRESSED";
})(PressurePlateState || (PressurePlateState = {}));
/** For `GridEntityType.TELEPORTER` (23). */
export var TeleporterState;
(function (TeleporterState) {
    TeleporterState[TeleporterState["NORMAL"] = 0] = "NORMAL";
    TeleporterState[TeleporterState["ACTIVATED"] = 1] = "ACTIVATED";
    /**
     * Set when a player stands on a teleport pad that has no corresponding pad for the player to be
     * sent to. When this happens, the pad turns black and deactivates.
     */
    TeleporterState[TeleporterState["DISABLED"] = 2] = "DISABLED";
})(TeleporterState || (TeleporterState = {}));
