/**
 * This is represented as an object instead of an enum due to limitations with TypeScript enums. (We
 * want this type to be a child of the `BitFlag` type.)
 *
 * @enum
 * @notExported
 * @rename DamageFlag
 */
declare const DamageFlagInternal: {
    /** 1 << 0 (1) */
    readonly NO_KILL: number;
    /**
     * e.g. fireplace
     *
     * 1 << 1 (2)
     */
    readonly FIRE: number;
    /** 1 << 2 (4) */
    readonly EXPLOSION: number;
    /** 1 << 3 (8) */
    readonly LASER: number;
    /** 1 << 4 (16) */
    readonly ACID: number;
    /** 1 << 5 (32) */
    readonly RED_HEARTS: number;
    /** 1 << 6 (64) */
    readonly COUNTDOWN: number;
    /** 1 << 7 (128) */
    readonly SPIKES: number;
    /** 1 << 8 (256) */
    readonly CLONES: number;
    /** 1 << 9 (512) */
    readonly POOP: number;
    /** 1 << 10 (1024) */
    readonly DEVIL: number;
    /** 1 << 11 (2048) */
    readonly ISSAC_HEART: number;
    /** 1 << 12 (4096) */
    readonly TNT: number;
    /** 1 << 13 (8192) */
    readonly INVINCIBLE: number;
    /** 1 << 14 (16384) */
    readonly SPAWN_FLY: number;
    /** 1 << 15 (32768) */
    readonly POISON_BURN: number;
    /** 1 << 16 (65536) */
    readonly CURSED_DOOR: number;
    /** 1 << 17 (131072) */
    readonly TIMER: number;
    /** 1 << 18 (262144) */
    readonly IV_BAG: number;
    /** 1 << 19 (524288) */
    readonly PITFALL: number;
    /** 1 << 20 (1048576) */
    readonly CHEST: number;
    /** 1 << 21 (2097152) */
    readonly FAKE: number;
    /** 1 << 22 (4194304) */
    readonly BOOGER: number;
    /** 1 << 23 (8388608) */
    readonly SPAWN_BLACK_HEART: number;
    /**
     * Comes from a strong impact. Can damage Tuff Twins or The Shell (e.g. Mom's foot, shockwaves,
     * rock tears).
     *
     * 1 << 24 (16777216)
     */
    readonly CRUSH: number;
    /** 1 << 25 (33554432) */
    readonly NO_MODIFIERS: number;
    /** 1 << 26 (67108864) */
    readonly SPAWN_RED_HEART: number;
    /** 1 << 27 (134217728) */
    readonly SPAWN_COIN: number;
    /** 1 << 28 (268435456) */
    readonly NO_PENALTIES: number;
    /** 1 << 29 (536870912) */
    readonly SPAWN_TEMP_HEART: number;
    /** 1 << 30 (1073741824) */
    readonly IGNORE_ARMOR: number;
    /** 1 << 31 (2147483648) */
    readonly SPAWN_CARD: number;
    /** 1 << 32 (4294967296) */
    readonly SPAWN_RUNE: number;
};
type DamageFlagValue = BitFlag & {
    readonly __damageFlagBrand: symbol;
};
type DamageFlagType = {
    readonly [K in keyof typeof DamageFlagInternal]: DamageFlagValue;
};
export declare const DamageFlag: DamageFlagType;
export type DamageFlag = DamageFlagType[keyof DamageFlagType];
export declare const DamageFlagZero: BitFlags<DamageFlagValue>;
export {};
//# sourceMappingURL=DamageFlag.d.ts.map