/**
 * This is represented as an object instead of an enum due to limitations with TypeScript enums. (We
 * want this type to be a child of the `BitFlag` type.)
 *
 * @enum
 * @notExported
 * @rename UseFlag
 */
declare const UseFlagInternal: {
    /**
     * Don't play use animations.
     *
     * 1 << 0 (1)
     */
    readonly NO_ANIMATION: number;
    /**
     * Don't add costume.
     *
     * 1 << 1 (2)
     */
    readonly NO_COSTUME: number;
    /**
     * Effect was triggered by an active item owned by the player.
     *
     * 1 << 2 (4)
     */
    readonly OWNED: number;
    /**
     * Allow the effect to trigger on non-main players (i.e. coop babies).
     *
     * 1 << 3 (8)
     */
    readonly ALLOW_NON_MAIN_PLAYERS: number;
    /**
     * D4 only: Reroll the player's active item.
     *
     * 1 << 4 (16)
     */
    readonly REMOVE_ACTIVE: number;
    /**
     * Effect was triggered a second time by Car Battery (or Tarot Cloth for cards).
     *
     * 1 << 5 (32)
     */
    readonly CAR_BATTERY: number;
    /**
     * Effect was triggered by Void.
     *
     * 1 << 6 (64)
     */
    readonly VOID: number;
    /**
     * Effect was mimicked by an active item (Blank Card, Placebo).
     *
     * 1 << 7 (128)
     */
    readonly MIMIC: number;
    /**
     * Never play announcer voice.
     *
     * 1 << 8 (256)
     */
    readonly NO_ANNOUNCER_VOICE: number;
    /**
     * This allows an item to spawn wisps when called from another item usage as the wisps generator
     * checks for `NO_ANIMATION`, so usually you want to use this with `NO_ANIMATION` call.
     *
     * 1 << 9 (512)
     */
    readonly ALLOW_WISP_SPAWN: number;
    /**
     * If set, forces UseActiveItem to use the CustomVarData argument instead of the active item's
     * stored VarData.
     *
     * 1 << 10 (1024)
     */
    readonly CUSTOM_VARDATA: number;
    /**
     * Don't display text in the HUD. (This is currently only used by Echo Chamber.)
     *
     * 1 << 11 (2048)
     */
    readonly NO_HUD: number;
};
type UseFlagValue = BitFlag & {
    readonly __useFlagBrand: symbol;
};
type UseFlagType = {
    readonly [K in keyof typeof UseFlagInternal]: UseFlagValue;
};
export declare const UseFlag: UseFlagType;
export type UseFlag = UseFlagType[keyof UseFlagType];
export declare const UseFlagZero: BitFlags<UseFlagValue>;
export {};
//# sourceMappingURL=UseFlag.d.ts.map